@@ -214,9 +214,13 @@ int convert_case(string &s)
 	s2.assign(s);
 
 	size_t p1 = s2.ufind("<body", 0);
+	if (p1 == std::string::npos)
+		return 1;
 	s1 = s2.substr(0, p1);
 	s2.erase(0, p1);
 	p1 = s2.ufind("</body", 0);
+	if (p1 == std::string::npos)
+		return 1;
 	s3 = s2.substr(p1);
 	s2.erase(p1);
 
@@ -273,10 +277,12 @@ void extract_fields()
 	FILE *html_file = fopen(fname.c_str(), "r");
 	char c = fgetc(html_file);
 	html_form.clear();
+
 	while (!feof(html_file)) {
 		html_form += c;
 		c = fgetc(html_file);
 	}
+
 	fclose(html_file);
 
 	if (convert_case(html_form)) {
@@ -1112,6 +1118,7 @@ void cb_custom_import_data()
 // test file integrity
 	if (filesize == 0) {
 		fl_alert2(_("Empty file"));
+        fclose (custom_datafile);
 		return;
 	}
 
@@ -1121,7 +1128,10 @@ void cb_custom_import_data()
 	fseek (custom_datafile, 0, SEEK_SET);
 	int retval = fread (buff, filesize, 1, custom_datafile);
 	fclose (custom_datafile);
-	if (retval != 1) return;
+	if (retval != 1) {
+        delete[] buff;
+        return;
+    }
 
 	custom_field = buff;
 // strip any cr-lf pairs if the file was a DOS text file
@@ -1317,7 +1327,10 @@ void load_custom_html_file()
 	}
 	fseek(dfile, 0, SEEK_END);
 	size_t fsize = ftell(dfile);
-	if (fsize <= 0) return;
+	if (fsize <= 0) {
+        fclose (dfile);
+        return;
+    }
 	fseek(dfile, 0, SEEK_SET);
 	transfer_custom_buffer.resize(fsize);
 	size_t r = fread((void *)transfer_custom_buffer.c_str(), 1, fsize, dfile);
