@@ -291,3 +291,44 @@ BT\n\
 NNNN\n\
 ";
 
+
+//======================================================================
+// GENERIC message templates
+//======================================================================
+
+const char mars_msg_html_template[] = "\
+<!DOCTYPE html PUBLIC \"-//W3C//DTD HTML 4.01//EN\" \"http://www.w3.org/TR/html4/strict.dtd\">\
+<html>\
+<head><meta content=\"text/html; charset=UTF-8\" http-equiv=\"content-type\">\
+<title>:TITLE:</title>\
+</head><body>\
+<table WIDTH=1000px BORDER=1 CELLPADDING=0 CELLSPACING=0>\
+<tbody>\
+<tr ALIGN=center>\
+<td COLSPAN=3 VALIGN=top BGCOLOR=#E9E9E9><big>GENERIC MARS STD MSG</big><br></td>\
+</tr>\
+</table><br>\
+<FONT face=monospace size=5><b><pre>\
+:pre: :dtg:\n\
+FM :fm:\n\
+TO :to:\n\
+BT\n\
+UNCLAS\n\
+:text:\n\
+BT\n\
+NNNN\n\
+</pre></b></FONT>\
+</body>\
+</html>";
+
+const char mars_msg_text_template[] = "\
+:pre: :dtg:\n\
+FM :fm:\n\
+TO :to:\n\
+BT\n\
+UNCLAS\n\
+:text:\n\
+BT\n\
+NNNN\n\
+";
+
