@@ -30,6 +30,7 @@
 #include <string>
 #include <cstdlib>
 #include <cstring>
+#include <string>
 #include <cstdio>
 #include <stdint.h>
 
@@ -41,8 +42,6 @@
 #include "flslider2.h"
 #include "gettext.h"
 
-using namespace std;
-
 Font_Browser* font_browser;
 
 // Font Color selected
@@ -283,7 +282,7 @@ void Font_Browser::fontFilter(filter_t filter)
 
 	int s = lst_Font->size();
 
-	static vector<bool> fixed;
+	static std::vector<bool> fixed;
 	if (fixed.empty()) {
 		Progress_Window pw(1, s, _("Reading fonts..."));
 		fixed.resize(s);
